@@ -337,13 +337,13 @@ class FargateToSqsProps:
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. An SQS Interface endpoint will be included in this VPC. Default: - none
         '''
         if isinstance(cluster_props, dict):
-            cluster_props = ClusterProps(**cluster_props)
+            cluster_props = aws_cdk.aws_ecs.ClusterProps(**cluster_props)
         if isinstance(dead_letter_queue_props, dict):
-            dead_letter_queue_props = QueueProps(**dead_letter_queue_props)
+            dead_letter_queue_props = aws_cdk.aws_sqs.QueueProps(**dead_letter_queue_props)
         if isinstance(queue_props, dict):
-            queue_props = QueueProps(**queue_props)
+            queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
         if isinstance(vpc_props, dict):
-            vpc_props = VpcProps(**vpc_props)
+            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
         if __debug__:
             type_hints = typing.get_type_hints(FargateToSqsProps.__init__)
             check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
